import { useState, useContext } from 'react'
import ReactDOM from 'react-dom'
import {
  BrowserRouter as Router,
  Switch,
  Redirect,
  Route,
  Link
} from 'react-router-dom'

import { CssBaseline } from '@material-ui/core';

import UserContext from './user-context'
import Login from './pages/login'
import Home from './pages/home'


const Secure = ({children}) => {
  const { token } = useContext(UserContext)
  if (!token) {
    return <Redirect to="/login" />
  }

  return children
}

const App = () => {
  const [token, setToken] = useState(localStorage.getItem('token'))

  return (
    <UserContext.Provider value={{ token, setToken }}>
      <Router>
        <CssBaseline />
        <Switch>
          <Route path="/login">
            <Login />
          </Route>

          <Route path="/">
            <Secure>
              <Home />
            </Secure>
          </Route>
        </Switch>
      </Router>
    </UserContext.Provider>
  )
}

ReactDOM.render(<App />, document.getElementById('app'))
